Core Operations {#tutorial_py_table_of_contents_core}
===============

-   @subpage tutorial_py_basic_ops

    Learn to read and
    edit pixel values, working with image ROI and other basic operations.

-   @subpage tutorial_py_image_arithmetics

    Perform arithmetic
    operations on images

-   @subpage tutorial_py_optimization

    Getting a solution is
    important. But getting it in the fastest way is more important. Learn to check the speed of your
    code, optimize the code etc.
